
#ifndef EL__PROTOCOL_FILE_CGI_H
#define EL__PROTOCOL_FILE_CGI_H

struct connection;

int execute_cgi(struct connection *);

#endif
